@@ -17,6 +17,9 @@ from cool.settings import cool_settings
 
 
 class CoolAutocompleteJsonView(BaseListView):
+    """
+    外键自动提示view
+    """
     paginate_by = 20
 
     def get(self, request, *args, **kwargs):
@@ -85,7 +88,7 @@ class CoolAutocompleteJsonView(BaseListView):
 
     @classmethod
     def has_perm(cls, request, app_label, model_name):
-        if cool_settings.AUTOCOMPLETE_CHECK_PERM:
+        if cool_settings.ADMIN_AUTOCOMPLETE_CHECK_PERM:
             return (
                     request.user.has_perm('%s.%s_%s' % (app_label, 'view', model_name)) or
                     request.user.has_perm('%s.%s_%s' % (app_label, 'change', model_name))
