@@ -165,6 +165,10 @@ def get_serializer_info(serializer_obj, force_many=False):
             ret[field_name] = [str(field.child_relation.label)]
         else:
             ret[field_name] = str(field.label)
+            if isinstance(field, fields.ChoiceField):
+                choices = ",".join(["%s:%s" % (k, v) for k, v in field.choices.items()])
+                if choices:
+                    ret[field_name] += " (%s)" % choices
     return [ret] if force_many else ret
 
 
@@ -207,16 +211,23 @@ def get_view_list(urlpattern=None, head='/', base_view=CoolBFFAPIView):
     return ret
 
 
-def get_api_info(base_view=CoolBFFAPIView, exclude_params=(), exclude_base_view_params=True, exclude_views=()):
+def get_api_info(base_view=CoolBFFAPIView, base_params=(), add_base_view_params=True, exclude_views=()):
     """
     获取api接口信息
+
+    :param base_view: 接口视图基类
+    :param base_params: 公共参数
+    :param add_base_view_params: 基类中参数增加到公共参数
+    :param exclude_views:  排除接口视图
     """
     assert issubclass(base_view, CoolBFFAPIView)
-    exclude_params = set(exclude_params)
-    if exclude_base_view_params:
+    base_params = list(base_params)
+    if add_base_view_params:
         opt = getattr(base_view, '_meta', None)
         param_fields = getattr(opt, 'param_fields', dict())
-        exclude_params.update(param_fields.keys())
+        for param_field in param_fields.keys():
+            if param_field not in base_params:
+                base_params.append(param_field)
 
     error_codes = ErrorCode.get_desc_dict()
 
@@ -232,8 +243,6 @@ def get_api_info(base_view=CoolBFFAPIView, exclude_params=(), exclude_base_view_
             if isinstance(field, fields.FileField):
                 has_file = True
                 post = True
-            if param in exclude_params:
-                continue
             if param in ('pass', 'password'):
                 post = True
             if isinstance(field, fields.CharField):
@@ -244,17 +253,24 @@ def get_api_info(base_view=CoolBFFAPIView, exclude_params=(), exclude_base_view_
 
         if no_len_count > 3 or length > 200:
             post = True
-
+        info = v['view_class'].get_view_info()
+        base_params_num = 0
+        for base_param in base_params:
+            if base_param in info['request_info']:
+                info['request_info'].move_to_end(base_param, False)
+                base_params_num += 1
+        params = list(info['request_info'].keys())[base_params_num:]
         apis.append({
             'name': v['name'],
             'url': v['url'],
             'ul_name': v['url'].replace('/', '_').strip('_'),
-            'info': v['view_class'].get_view_info(),
+            'info': info,
+            'self_params': params,
             'suggest_method': 'POST' if post else 'GET',
             'content_type': 'multipart/form-data' if has_file else 'application/x-www-form-urlencoded',
         })
     return {
-        'exclude_params': list(exclude_params),
+        'base_params': base_params,
         'error_codes': error_codes,
         'apis': apis
     }
@@ -270,23 +286,43 @@ def get_api_doc(
 ):
     """
     生成api文档
+
+    :param request: 请求request
+    :param template_name: 接口模板
+    :param base_view: 接口视图基类
+    :param exclude_params: 排除参数
+    :param exclude_base_view_params: 是否排除基类中参数
+    :param exclude_views:  排除接口视图
     """
     api_info = get_api_info(base_view, exclude_params, exclude_base_view_params, exclude_views)
     api_info['server'] = request.build_absolute_uri("/")[:-1] if request is not None else '/'
     return render_to_string(template_name, api_info, request)
 
 
-def get_api_doc_html(request, *args, **kwargs):
+def get_api_doc_html(
+    request,
+    *args,
+    md_template_name='cool/views/api_doc.md',
+    base_view=CoolBFFAPIView,
+    exclude_params=(),
+    exclude_base_view_params=True,
+    exclude_views=(),
+    title=_('Api Document'),
+    toc_left=True,
+    **kwargs
+):
     """
     生成api文档（markdown转html，依赖markdown）
+
+    :param request: 请求request
+    :param md_template_name: 接口模板
+    :param base_view: 接口视图基类
+    :param exclude_params: 排除参数
+    :param exclude_base_view_params: 是否排除基类中参数
+    :param exclude_views:  排除接口视图
+    :param title: 文档标题
+    :param toc_left: 宽浏览器中目录显示在左侧
     """
-    md_template_name = kwargs.get('md_template_name', 'cool/views/api_doc.md')
-    base_view = kwargs.get('base_view', CoolBFFAPIView)
-    exclude_params = kwargs.get('exclude_params', ())
-    exclude_base_view_params = kwargs.get('exclude_base_view_params', True)
-    exclude_views = kwargs.get('exclude_views', ())
-    title = kwargs.get('title', _('Api Document'))
-    toc_left = kwargs.get('toc_left', True)
     md = get_api_doc(
         request=request,
         template_name=md_template_name,
